import requests


class Client(object):

    @staticmethod
    def headers():

        headers = {'User-Agent': 'Mozilla/5.0 (Linux; Android 5.1; MZ-m1 metal Build/LMY47I) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0'}

        return headers

    @staticmethod
    def get(url: str, params: dict = '', headers: dict = '', proxies: dict = ''):

        headers = headers if headers else Client.headers()

        try:
            response = requests.get(url, params, headers=headers, proxies=proxies)
    
            return response
        except Exception as e:
            return e




from probable_happiness.Client import Client


class Artist(object):

    @staticmethod
    def get_class():
        url = "http://m.kugou.com/singer/class&json=true"
        response = Client.get(url)

        return response.json()

    @staticmethod
    def list(id: int, page: int = 1):
        url = 'http://m.kugou.com/singer/list/' + str(id)
        params = {'page': page, 'json': 'true'}

        response = Client.get(url, params=params)

        return dict(response.json())

    @staticmethod
    def info(id: int, page: int = 1):
        url = 'http://m.kugou.com/singer/info/' + str(id)
        params = {'page': page, 'json': 'true'}

        response = Client.get(url, params=params)

        return dict(response.json())

    @staticmethod
    def song(id: int, page: int = 1):
        response = Artist.info(id, page)['songs']

        return dict(response.json())


class Song(object):

    @staticmethod
    def new(type: int = 1):
        url = "http://mobilecdnbj.kugou.com/api/v3/rank/newsong"
        params = {'type': type, 'pagesize': 100, 'version': 9259, 'with_cover': 1, 'area_code': 1}

        response = Client.get(url, params)

        return dict(response.json())

    @staticmethod
    def info(hash: str):
        url = 'http://m.kugou.com/app/i/getSongInfo.php'
        params = {'cmd': 'playInfo', 'hash': hash}

        response = Client.get(url, params=params)

        return dict(response.json())

    @staticmethod
    def index(hash: str):
        data = Album.special_recommend(hash)

        index = {
            'hash': hash,
            'index': data['data']['info']['kugou_index']
        }

        return index


class Album(object):

    @staticmethod
    def info(album_id: int):
        url = "http://m.kugou.com/app/i/getablum.php"

        params = {'type': '1', 'ablumid': album_id}
        response = Client.get(url, params=params)

        return dict(response.json())

    @staticmethod
    def special_recommend(hash: str):
        url = "http://servicebj.mobile.kugou.com/v1/yueku/special_album_recommend"

        params = {'hash': hash, 'api_ver': '2'}
        response = Client.get(url, params=params)

        return dict(response.json())



__version__ = '0.0.4'
__author__ = u'Teakowa'
__author_email__ = 'git@teakowa.com'
__copyright__ = '2019 Teakowa'
__url__ = 'https://github.com/Teakowa/probable-happiness'


def get_version():
    return __version__



from setuptools import setup, find_packages
import probable_happiness

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="probable-happiness",
    version=probable_happiness.__version__,
    author=probable_happiness.__author__,
    author_email=probable_happiness.__author_email__,
    description="A library for music apis",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=probable_happiness.__url__,
    package_dir={'': '.'},
    packages=find_packages('.'),
    license='Anti 996 LICENSE',
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python :: 3.7",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'requests==2.22.0'
    ],
)
